from datetime import datetime


class Perfov:
    def __init__(self) -> None:
        self.start_time = datetime.now()
        self.last_checkpoint = None

    def start(self):
        self.start_time = datetime.now()

    def checkpoint(self, label):
        start_time = (
            self.last_checkpoint
            if self.last_checkpoint is not None
            else self.start_time
        )
        now = datetime.now()
        duration = now - start_time
        self.last_checkpoint = now
        Perfov._print_duration(duration, label)

    def finish(self):
        duration = datetime.now() - self.start_time
        Perfov._print_duration(duration, label="All")

    def _print_duration(duration, label=None):
        print_string = f"{label} process took {duration}"
        print(print_string)




from setuptools import setup, find_packages

VERSION = "0.0.1"
DESCRIPTION = "A performance monitor package"
LONG_DESCRIPTION = "A package that makes it easy to monitor process time"

setup(
    name="perfov",
    version=VERSION,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    author="Mert Cobanov",
    author_email="mertcobanov@gmail.com",
    license="MIT",
    packages=find_packages(),
    install_requires=[],
    keywords="timer",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
    ],
)
